==> modx-2.0.7-pl-ja.zip: modx-2.0.7-pl-ja/core/lexicon/en/tv.inc.php <==
<?php
/**
 * TV English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['has_access'] = 'Has Access?';
$_lang['rank'] = 'Rank';
$_lang['rendering_options'] = 'Rendering Options';
$_lang['tv'] = 'Template Variable';
$_lang['tv_access_msg'] = 'Select the Resource Groups that this Template Variable belongs to. Only users with access to the Groups selected will be able to modify this TV. If no Groups are selected, all users with access to the Manager will be able to modify the TV.';
$_lang['tv_binding_msg'] = 'This field supports data source bindings using the @ commands';
$_lang['tv_caption'] = 'Caption';
$_lang['tv_change_template_msg'] = 'Changing this template will cause the page to reload the Template Variables, losing any unsaved changes.<br /><br /> Are you sure you want to change this template?';
$_lang['tv_description'] = 'Description';
$_lang['tv_err_delete'] = 'An error occurred while deleting the template variable.';
$_lang['tv_err_duplicate'] = 'An error occurred while trying to duplicate the template variable.';
$_lang['tv_err_duplicate_templates'] = 'An error occurred while duplicating the TV templates.';
$_lang['tv_err_duplicate_documents'] = 'An error occurred while duplicating TV documents.';
$_lang['tv_err_duplicate_documentgroups'] = 'An error occurred while duplicating TV document groups.';
$_lang['tv_err_exists_name'] = 'A Template Variable already exists with the name "[[+name]]".';
$_lang['tv_err_invalid_name'] = 'You have invalid characters in your Template Variable name.';
$_lang['tv_err_locked'] = 'Template variable locked!';
$_lang['tv_err_nf'] = 'Template variable not found.';
$_lang['tv_err_nfs'] = 'Template variable not found with key: [[+id]]';
$_lang['tv_err_ns'] = 'Template variable not specified.';
$_lang['tv_err_reserved_name'] = 'A template variable cannot have the same name as a Resource field.';
$_lang['tv_err_save_access_permissions'] = 'An error occured while attempting to save template variable access permissions.';
$_lang['tv_err_save'] = 'An error occurred while saving the template variable.';
$_lang['tv_inuse'] = 'The following document(s) are currently using this Template Variable. To continue with the delete operation click the Delete button otherwise click the Cancel button.';
$_lang['tv_lock'] = 'Lock variable for editing';
$_lang['tv_lock_msg'] = 'Users must have the edit_locked attribute in order to edit this Template Variable.';
$_lang['tv_management_msg'] = 'Manage additional custom content fields (Template Variables) for your documents.';
$_lang['tv_msg'] = 'Add or edit template variables here. Template Variables must be assigned to templates in order to access them from snippets and documents.';
$_lang['tv_name'] = 'Variable Name';
$_lang['tv_new'] = 'New Template Variable';
$_lang['tv_novars'] = 'No Template Variables found';
$_lang['tv_properties'] = 'Default Properties';
$_lang['tv_rank'] = 'Sort Order';
$_lang['tv_reset_params'] = 'Reset parameters';
$_lang['tv_tmpl_access'] = 'Template Access';
$_lang['tv_tmpl_access_msg'] = 'Select the Templates that are allowed to access this Template Variable.';
$_lang['tv_widget'] = 'Widget';
$_lang['tv_widget_prop'] = 'Widget Properties';
$_lang['tvd_err_remove'] = 'An error occurred while trying to remove the template variable from the document.';
$_lang['tvdg_err_remove'] = 'An error occurred while trying to remove the template variable from the document group.';
$_lang['tvdg_err_save'] = 'An error occurred while trying to attach the template variable to the document group.';
$_lang['tvs'] = 'Template Variables';
$_lang['tvt_err_nf'] = 'Template Variable does not have access to the specified Template.';
$_lang['tvt_err_remove'] = 'An error occurred while trying to remove the template variable from the template.';
$_lang['tvt_err_save'] = 'An error occurred while trying to attach the template variable to the template.';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/tv.inc.php <==
<?php
/**
 * TV English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['has_access'] = 'Has Access?';
$_lang['rank'] = 'Rank';
$_lang['rendering_options'] = 'Rendering Options';
$_lang['tv'] = 'Template Variable';
$_lang['tv_access_msg'] = 'Select the Resource Groups that this Template Variable belongs to. Only users with access to the Groups selected will be able to modify this TV. If no Groups are selected, all users with access to the Manager will be able to modify the TV.';
$_lang['tv_binding_msg'] = 'This field supports data source bindings using the @ commands';
$_lang['tv_caption'] = 'Caption';
$_lang['tv_change_template_msg'] = 'Changing this template will cause the page to reload the Template Variables, losing any unsaved changes.<br /><br /> Are you sure you want to change this template?';
$_lang['tv_desc_caption'] = 'The text that will be used beside the TV when editing it in a Resource.';
$_lang['tv_desc_category'] = 'The Category this TV belongs in.';
$_lang['tv_desc_description'] = 'A short description of this TV.';
$_lang['tv_desc_name'] = 'The name of this TV. It will be available using the [[*NameOfTV]] tag.';
$_lang['tv_description'] = 'Description';
$_lang['tv_err_delete'] = 'An error occurred while deleting the template variable.';
$_lang['tv_err_duplicate'] = 'An error occurred while trying to duplicate the template variable.';
$_lang['tv_err_duplicate_templates'] = 'An error occurred while duplicating the TV templates.';
$_lang['tv_err_duplicate_documents'] = 'An error occurred while duplicating TV documents.';
$_lang['tv_err_duplicate_documentgroups'] = 'An error occurred while duplicating TV document groups.';
$_lang['tv_err_exists_name'] = 'A Template Variable already exists with the name "[[+name]]".';
$_lang['tv_err_invalid_name'] = 'You have invalid characters in your Template Variable name.';
$_lang['tv_err_locked'] = 'Template variable locked!';
$_lang['tv_err_nf'] = 'Template variable not found.';
$_lang['tv_err_nfs'] = 'Template variable not found with key: [[+id]]';
$_lang['tv_err_ns'] = 'Template variable not specified.';
$_lang['tv_err_reserved_name'] = 'A template variable cannot have the same name as a Resource field.';
$_lang['tv_err_save_access_permissions'] = 'An error occured while attempting to save template variable access permissions.';
$_lang['tv_err_save'] = 'An error occurred while saving the template variable.';
$_lang['tv_inuse'] = 'The following document(s) are currently using this Template Variable. To continue with the delete operation click the Delete button otherwise click the Cancel button.';
$_lang['tv_input_options'] = 'Input Options';
$_lang['tv_input_options_msg'] = '<p>Here you can edit the input options for the Template Variable, specific to the type of input render that you select.</p>';
$_lang['tv_lock'] = 'Lock variable for editing';
$_lang['tv_lock_msg'] = 'Users must have the edit_locked attribute in order to edit this Template Variable.';
$_lang['tv_management_msg'] = 'Manage additional custom content fields (Template Variables) for your documents.';
$_lang['tv_msg'] = 'Add or edit template variables here. Template Variables must be assigned to templates in order to access them from snippets and documents.';
$_lang['tv_name'] = 'Variable Name';
$_lang['tv_new'] = 'New Template Variable';
$_lang['tv_novars'] = 'No Template Variables found';
$_lang['tv_output_options'] = 'Output Options';
$_lang['tv_output_options_msg'] = '<p>Here you can edit the output options for the Template Variable, specific to the type of output render that you select.</p>';
$_lang['tv_properties'] = 'Default Properties';
$_lang['tv_rank'] = 'Sort Order';
$_lang['tv_reset_params'] = 'Reset parameters';
$_lang['tv_sources.intro_msg'] = 'Here you can assign the Media Sources that are to be used for this TV in each specified Context. Double-click on the Source name in the grid to change it.';
$_lang['tv_tmpl_access'] = 'Template Access';
$_lang['tv_tmpl_access_msg'] = 'Select the Templates that are allowed to access this Template Variable.';
$_lang['tv_widget'] = 'Widget';
$_lang['tv_widget_prop'] = 'Widget Properties';
$_lang['tvd_err_remove'] = 'An error occurred while trying to remove the template variable from the document.';
$_lang['tvdg_err_remove'] = 'An error occurred while trying to remove the template variable from the document group.';
$_lang['tvdg_err_save'] = 'An error occurred while trying to attach the template variable to the document group.';
$_lang['tvs'] = 'Template Variables';
$_lang['tvt_err_nf'] = 'Template Variable does not have access to the specified Template.';
$_lang['tvt_err_remove'] = 'An error occurred while trying to remove the template variable from the template.';
$_lang['tvt_err_save'] = 'An error occurred while trying to attach the template variable to the template.';
